@@ -1,8 +1,10 @@
+# frozen_string_literal: true
+
 describe WPScan::Finders::Users::LoginErrorMessages do
   subject(:finder) { described_class.new(target) }
   let(:target)     { WPScan::Target.new(url) }
   let(:url)        { 'http://wp.lab/' }
-  let(:fixtures)   { File.join(FINDERS_FIXTURES, 'users', 'login_error_messages') }
+  let(:fixtures)   { FINDERS_FIXTURES.join('users', 'login_error_messages') }
 
   describe '#aggressive' do
     xit
